==> remotefs-0.1.1.crate: remotefs-0.1.1/src/fs/welcome.rs <==
//! ## Welcome
//!
//! welcome data type

/**
 * MIT License
 *
 * remotefs - Copyright (c) 2021 Christian Visintin
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/// Structure holding all data related to a successful connection and authentication
/// on remote host.
#[derive(Debug, Default)]
pub struct Welcome {
    /// Welcome message / banner
    pub banner: Option<String>,
}

impl Welcome {
    /// Set welcome message or banner
    pub(crate) fn banner(mut self, banner: Option<String>) -> Self {
        self.banner = banner;
        self
    }
}

#[cfg(test)]
mod test {
    use super::*;

    use pretty_assertions::assert_eq;

    #[test]
    fn should_create_welcome_type() {
        let welcome = Welcome::default();
        assert!(welcome.banner.is_none());
        let welcome = Welcome::default().banner(Some("Hello, world!".to_string()));
        assert_eq!(welcome.banner.as_deref().unwrap(), "Hello, world!");
    }
}

==> remotefs-0.2.0.crate: remotefs-0.2.0/src/fs/welcome.rs <==
//! ## Welcome
//!
//! welcome data type

/**
 * MIT License
 *
 * remotefs - Copyright (c) 2021 Christian Visintin
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/// Structure holding all data related to a successful connection and authentication
/// on remote host.
#[derive(Debug, Default)]
pub struct Welcome {
    /// Welcome message / banner
    pub banner: Option<String>,
}

impl Welcome {
    /// Set welcome message or banner
    pub fn banner(mut self, banner: Option<String>) -> Self {
        self.banner = banner;
        self
    }
}

#[cfg(test)]
mod test {
    use super::*;

    use pretty_assertions::assert_eq;

    #[test]
    fn should_create_welcome_type() {
        let welcome = Welcome::default();
        assert!(welcome.banner.is_none());
        let welcome = Welcome::default().banner(Some("Hello, world!".to_string()));
        assert_eq!(welcome.banner.as_deref().unwrap(), "Hello, world!");
    }
}
